$def with (passphrase_words)
$var title: Welcome

<p>This is your passphrase. Write it down.</p>

<pre><big>$" ".join(passphrase_words)</big></pre>

<p>Then continue to your <a href=/>home page</a>.</p>
