$def with (entry, mentions)
$ p = entry["published"][0]
$ breadcrumbs = (p.year, p.year, p.format("MM"), p.format("MMM"),
$                p.format("DD"), p.format("D"))
$var breadcrumbs = breadcrumbs

<article class=h-entry>
$ type = discover_post_type(entry)
$if type == "note":
    <div class=e-content>$:mkdn(entry["content"][0])</div>
$elif type == "bookmark":
    $ bookmark = entry["bookmark-of"][0]
    $var title: Bookmarked $bookmark
    <p><big>Bookmarked <a class=u-bookmark-of
    href=$bookmark>$bookmark</a></big></p>
$elif type == "like":
    $ like = entry["like-of"][0]
    $var title: Liked $like
    <p class=p-name><big class="h-cite u-like-of">Liked
    <a class="p-name u-url" href=$like>$like</a></big></p>
$elif type == "rsvp":
    $ event = entry["in-reply-to"][0]
    $var title: RSVP'd $entry["rsvp"] to $event["name"]
    <p><big>RSVP'd <code>$entry["rsvp"]</code> <a class=u-bookmark-of
    href=$event["url"]>$event["name"]</a></big></p>
$ a = entry["author"]
<p class="p-author h-card"><a class="u-url p-name"
href=$a["url"][0]>$a["name"][0]</a>
<small><strong>$entry["visibility"][0]</strong></small></p>
<p><small><a class=u-url href=$entry["url"][0]><time class=dt-published
datetime="$entry['published'][0].isoformat()">\
$entry["published"][0].diff_for_humans()</time></a></small></p>
</article>

<footer>
$for mention in mentions:
    <div>
    $if mention["data"]:
        $ a = mention["data"]["author"]
        $ comment_type = mention["data"]["comment_type"][0]
        $if comment_type == "like":
            $emoji.emojize(":red_heart:")
    <small>
    $if mention["data"]:
        <a href=$a["url"]>$a["name"]</a>
    <a href=$mention["source"]><time class=dt-published
    datetime="$mention['received'].isoformat()">\
    $mention["received"].diff_for_humans()</time></a>
    </small></div>
</footer>

<style>
div.e-content {
    font-size: 2em; }
</style>


$# $elif type == "identification":
$#     $ identification = entry["identification-of"][0]
$#     $var title: Identified $identification["name"]
$#     <p><big>Identified <a class=u-identification-of
$#     href=$identification["url"]>$identification["name"]</a></big></p>
$# $elif type == "follow":
$#     $ follow = entry["follow-of"][0]
$#     $var title: Followed $follow["name"]
$#     <p><big>Followed <a class=u-follow-of
$#     href=$follow["url"]>$follow["name"]</a></big></p>
