$def with ()
$var title: Settings

<form action=/settings method=post>
<label><input type=radio name=theme value=none> none</label>
<label><input type=radio name=theme value=solarized> Solarized</label>
<button>Save</button>
</form>
